@@ -10,6 +10,7 @@ from pyxodr.road_objects.lane import ConnectionPosition, TrafficOrientation
 from pyxodr.road_objects.lane_section import LaneSection
 from pyxodr.utils import cached_property
 from pyxodr.utils.array import interpolate_path
+from pyxodr.utils.curved_text import CurvedText
 
 
 class Road:
@@ -23,16 +24,24 @@ class Road:
     resolution : float, optional
         Spatial resolution (in m) with which to create the road (and associated road
         object) coordinates, by default 0.1
+    ignored_lane_types : Set[str], optional
+        A set of lane types that should not be read from the OpenDRIVE file. If
+        unspecified, no types are ignored.
     """
 
     def __init__(
         self,
         road_xml: etree._Element,
         resolution: float = 0.1,
+        ignored_lane_types: Optional[Set[str]] = None,
     ):
         self.road_xml = road_xml
         self.resolution = resolution
 
+        self.ignored_lane_types = (
+            set([]) if ignored_lane_types is None else ignored_lane_types
+        )
+
         # We'll store both successor and predecessor data as sometimes one of these
         # (maybe just successor?) will point to a junction rather than a road, so we
         # need the other to reconstruct the connectivity
@@ -329,7 +338,7 @@ class Road:
     @property
     def id(self):
         """Get the OpenDRIVE ID of this road."""
-        return int(self["id"])
+        return self["id"]
 
     def _link_lane_sections(self):
         """
@@ -480,25 +489,26 @@ class Road:
                     lane_sub_reference_line,
                     lane_z_coordinates,
                     self.traffic_orientation,
+                    ignored_lane_types=self.ignored_lane_types,
                 )
             )
 
         return lane_sections
 
     @cached_property
-    def successor_ids(self) -> Set[int]:
+    def successor_ids(self) -> Set[str]:
         """Get the OpenDRIVE IDs of the successor roads to this road."""
         _successor_ids = set()
         for successor_xml in self.road_xml.find("link").findall("successor"):
-            _successor_ids.add(int(successor_xml.attrib["elementId"]))
+            _successor_ids.add(successor_xml.attrib["elementId"])
         return _successor_ids
 
     @cached_property
-    def predecessor_ids(self) -> Set[int]:
+    def predecessor_ids(self) -> Set[str]:
         """Get the OpenDRIVE IDs of the predecessor roads to this road."""
         _predecessor_ids = set()
         for predecessor_xml in self.road_xml.find("link").findall("predecessor"):
-            _predecessor_ids.add(int(predecessor_xml.attrib["elementId"]))
+            _predecessor_ids.add(predecessor_xml.attrib["elementId"])
         return _predecessor_ids
 
     @cached_property
@@ -520,12 +530,12 @@ class Road:
     def junction_connecting_ids(self) -> Dict[str, Set[int]]:
         """Return the IDs of all junctions that connect to this road."""
         predecessor_junction_ids = [
-            int(predecessor_xml.attrib["elementId"])
+            predecessor_xml.attrib["elementId"]
             for predecessor_xml in self.road_xml.find("link").findall("predecessor")
             if predecessor_xml.attrib["elementType"] == "junction"
         ]
         successor_junction_ids = [
-            int(successor_xml.attrib["elementId"])
+            successor_xml.attrib["elementId"]
             for successor_xml in self.road_xml.find("link").findall("successor")
             if successor_xml.attrib["elementType"] == "junction"
         ]
@@ -542,6 +552,7 @@ class Road:
         axis: plt.Axes,
         plot_start_and_end: bool = False,
         line_scale_factor: float = 1.0,
+        label_size: Optional[int] = None,
     ) -> plt.Axes:
         """
         Plot a visualisation of this road on a provided axis object.
@@ -555,6 +566,10 @@ class Road:
             with red cross), by default False
         line_scale_factor : float, optional
             Scale all lines thicknesses up by this factor, by default 1.0.
+        label_size : int, optional
+            If specified, text of this font size will be displayed along the road line
+            of the form "r_n" where n is the ID of this road. By default None, resulting
+            in no labels.
 
         Returns
         -------
@@ -565,6 +580,16 @@ class Road:
         global_coords = self.reference_line
         global_coords_len = len(global_coords)
         axis.plot(*global_coords.T, linewidth=0.05 * line_scale_factor)
+        if label_size is not None:
+            x, y = global_coords[int(len(global_coords) // 2) - 1 :].T
+            CurvedText(
+                x=x,
+                y=y,
+                text=f"r_{self.id}",
+                va="bottom",
+                axes=axis,
+                fontsize=3,
+            )
         if plot_start_and_end:
             axis.scatter(
                 [global_coords[0][0]], [global_coords[0][1]], marker="o", c="green", s=4
